aboutsummaryrefslogtreecommitdiff
path: root/internal/lsp/cache/mod_tidy.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/lsp/cache/mod_tidy.go')
-rw-r--r--internal/lsp/cache/mod_tidy.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/internal/lsp/cache/mod_tidy.go b/internal/lsp/cache/mod_tidy.go
index b7730cff8..dbf4ecc23 100644
--- a/internal/lsp/cache/mod_tidy.go
+++ b/internal/lsp/cache/mod_tidy.go
@@ -126,8 +126,8 @@ func (s *snapshot) ModTidyHandle(ctx context.Context, realfh source.FileHandle)
// We want to run "go mod tidy" to be able to diff between the real and the temp files.
args := append([]string{"mod", "tidy"}, cfg.BuildFlags...)
if _, err := source.InvokeGo(ctx, folder, cfg.Env, args...); err != nil {
- // Ignore parse errors here. They'll be handled below.
- if !strings.Contains(err.Error(), "errors parsing go.mod") {
+ // Ignore parse errors and concurrency errors here. They'll be handled below.
+ if !strings.Contains(err.Error(), "errors parsing go.mod") && !modConcurrencyError.MatchString(err.Error()) {
data.err = err
return data
}